@@ -3,7 +3,6 @@ import unittest
 
 from veliberator.models import db_connection
 
-from tests.test_popchecker import suite as popchecker_suite
 from tests.test_models import suite as models_suite
 from tests.test_xml_wrappers import suite as xml_suite
 from tests.test_station import suite as station_suite
@@ -11,8 +10,7 @@ from tests.test_cartography import suite as cartography_suite
 
 db_connection('sqlite:///:memory:')
 
-global_test_suite = unittest.TestSuite([popchecker_suite,
-                                        models_suite,
+global_test_suite = unittest.TestSuite([models_suite,
                                         xml_suite,
                                         station_suite,
                                         cartography_suite,])
